@@ -315,7 +315,7 @@ def rearrange_dims(dims, in_format, dataformats="NCHW"):
                 in_format_array.append(int(c_to_i[c_in]))
                 dataformat_array.append(int(c_to_i[c_out]))
         for mapping in mappings:
-            mapped = list(in_format_array[mapping[0]], in_format_array[mapping[1]], in_format_array[mapping[2]])
+            mapped = list((in_format_array[mapping[0]], in_format_array[mapping[1]], in_format_array[mapping[2]]))
             if mapped == dataformat_array:
                 return mapping
 
@@ -327,7 +327,7 @@ def rearrange_dims(dims, in_format, dataformats="NCHW"):
         dims = (1, height, width)
     elif len(dims) == 3:
         mapping = find_mapping(in_format, dataformats)
-        dims = tuple(dims[mapping[0]], dims[mapping[1]], dims[mapping[2]])
+        dims = tuple([dims[mapping[0]], dims[mapping[1]], dims[mapping[2]]])
         
     else:
         raise ValueError(f"Wrong dimension {dims} for an input.")
